##
##  curl.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         curl
Summary:      Batch Client for HTTP, HTTPS, FTP, LDAP and DICT protocol
URL:          http://curl.haxx.se/
Vendor:       Daniel Stenberg
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Web
License:      MIT-style
Version:      8.13.0
Release:      20250402

#   package options
%option       with_ssl        yes
%option       with_zlib       yes
%option       with_http2      yes
%option       with_http3      yes
%option       with_websockets yes
%option       with_brotli     no
%option       with_ssh        no
%option       with_idn        no
%option       with_ares       no
%option       with_kerberos   no
%option       with_ldap       no
%option       with_rtmp       no
%option       with_psl        no

#   package option dependencies
%if "%{with_ldap}" == "yes" && "%{with_ssl}" == "no"
%undefine     with_ssl
%define       with_ssl        yes
%endif

#   list of sources
Source0:      http://curl.haxx.se/download/curl-%{version}.tar.xz
Patch0:       curl.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc
PreReq:       OpenPKG, openpkg >= 20160101, x509
%if "%{with_ssl}" == "yes"
BuildPreReq:  openssl3 >= 3
PreReq:       openssl3 >= 3
%endif
%if "%{with_zlib}" == "yes"
BuildPreReq:  zlib
PreReq:       zlib
%endif
%if "%{with_brotli}" == "yes"
BuildPreReq:  brotli
PreReq:       brotli
%endif
%if "%{with_idn}" == "yes"
BuildPreReq:  libidn2, pkgconfig
PreReq:       libidn2
%endif
%if "%{with_ares}" == "yes"
BuildPreReq:  ares
PreReq:       ares
%endif
%if "%{with_kerberos}" == "yes"
BuildPreReq:  KERBEROS
PreReq:       KERBEROS
%endif
%if "%{with_ssh}" == "yes"
BuildPreReq:  libssh2
PreReq:       libssh2
%endif
%if "%{with_ldap}" == "yes"
BuildPreReq:  openldap, openssl3
PreReq:       openldap, openssl3
%endif
%if "%{with_http2}" == "yes"
BuildPreReq:  nghttp2
PreReq:       nghttp2
%endif
%if "%{with_http3}" == "yes"
BuildPreReq:  nghttp3
PreReq:       nghttp3
%endif
%if "%{with_rtmp}" == "yes"
BuildPreReq:  librtmp, pkgconfig
PreReq:       librtmp
%endif
%if "%{with_psl}" == "yes"
BuildPreReq:  libpsl, pkgconfig
PreReq:       libpsl
%endif

%description
    Curl is the tool for transferring files with URL syntax, supporting FTP,
    HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP. Curl supports HTTPS
    certificates, HTTP POST, HTTP PUT, FTP uploading, HTTP form based upload,
    proxies, cookies, user+password authentication, file transfer resume and a
    busload of other useful tricks.

%track
    prog curl = {
        version   = %{version}
        url       = http://curl.haxx.se/download/
        regex     = curl-(__VER__)\.tar\.xz
    }

%prep
    %setup -q
    %patch -p0

%build
    ( echo 'ac_cv_header_openssl_engine_h=no'
      echo 'lt_cv_prog_compiler_c_o_F77=no'
      echo 'lt_cv_sys_max_cmd_len=100'
    ) >config.cache
    export CC="%{l_cc}"
    export CXX="%{l_cxx}"
    export CFLAGS="%{l_cflags -O}"
    export CPPFLAGS="%{l_cppflags openssl3 .}"
    export LDFLAGS="%{l_ldflags openssl3 .}"
    export LIBS=""
%if "%{with_idn}" == "yes"
    CFLAGS="$CFLAGS `pkg-config --cflags libidn2`"
    LIBS="$LIBS `pkg-config --libs libidn2`"
%endif
%if "%{with_ldap}" == "yes"
    LIBS="-lldap -llber -lssl -lcrypto"
%endif
%if "%{with_psl}" == "yes"
    CFLAGS="$CFLAGS `pkg-config --cflags libpsl`"
    LIBS="$LIBS `pkg-config --libs libpsl`"
%endif
%if "%{with_brotli}" == "yes"
    LIBS="$LIBS -lbrotlicommon"
%endif
    export GREP="grep"
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --datarootdir=%{l_prefix} \
        --datadir=%{l_prefix}/share \
%if "%{with_ssl}" == "yes"
        --with-openssl=%{l_prefix} \
        --with-openssl-quic \
        --with-default-ssl-backend=openssl \
        --with-ca-bundle=%{l_prefix}/etc/x509/public-ca.crt.pem \
%else
        --without-ssl \
%endif
%if "%{with_zlib}" == "yes"
        --with-zlib=%{l_prefix} \
%else
        --without-zlib \
%endif
%if "%{with_brotli}" == "yes"
        --with-brotli=%{l_prefix} \
%else
        --without-brotli \
%endif
%if "%{with_idn}" == "yes"
        --with-libidn2=%{l_prefix} \
%else
        --without-libidn2 \
%endif
%if "%{with_ares}" == "yes"
        --enable-ares=%{l_prefix} \
%else
        --disable-ares \
%endif
%if "%{with_kerberos}" == "yes"
        --with-gssapi=%{l_prefix} \
%else
        --without-gssapi \
%endif
%if "%{with_ssh}" == "yes"
        --with-libssh2=%{l_prefix} \
%else
        --without-libssh2 \
%endif
%if "%{with_ldap}" == "yes"
        --enable-ldap \
        --enable-ldaps \
        --with-ldap-lib=ldap \
        --with-lber-lib=lber \
%else
        --disable-ldap \
        --disable-ldaps \
%endif
%if "%{with_http2}" == "yes"
        --with-nghttp2 \
%else
        --without-nghttp2 \
%endif
%if "%{with_http3}" == "yes"
        --with-nghttp3 \
%else
        --without-nghttp3 \
%endif
%if "%{with_rtmp}" == "yes"
        --with-librtmp \
%else
        --without-librtmp \
%endif
%if "%{with_websockets}" == "yes"
        --enable-websockets \
%else
        --disable-websockets \
%endif
%if "%{with_psl}" == "yes"
        --with-libpsl \
%else
        --without-libpsl \
%endif
        --disable-ipv6 \
        --disable-threaded-resolver \
        --disable-pthreads \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/zsh
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
%if "%{with_ssl}" == "yes"
        %{l_files_std} \
        '%config %{l_prefix}/etc/curl/*'
%else
        %{l_files_std}
%endif

%files -f files

%clean

